summaryrefslogtreecommitdiff
path: root/cmake/modules/FindSPANDSP.cmake
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2016-12-06 20:49:12 +0100
committerPeter Wu <peter@lekensteyn.nl>2016-12-07 00:51:14 +0000
commitfc4bb7eb7413affa63049516c4dbc46ca272abea (patch)
tree6bffd44f7b8bd8be9e9a7178bdbc3688093e14f3 /cmake/modules/FindSPANDSP.cmake
parent47829b9611b613425aa0a314224863b02b915ea2 (diff)
downloadwireshark-fc4bb7eb7413affa63049516c4dbc46ca272abea.tar.gz
Change SpanDSP capitalization
Many capitalization can be found for this library (spandsp, Spandsp, SpanDSP), let's use the one found in the library README and in its spec file. Change-Id: Ia66b723e5d582a6218da1b6366b7d4859272f80c Reviewed-on: https://code.wireshark.org/review/19122 Reviewed-by: Peter Wu <peter@lekensteyn.nl>
Diffstat (limited to 'cmake/modules/FindSPANDSP.cmake')
-rw-r--r--cmake/modules/FindSPANDSP.cmake16
1 files changed, 8 insertions, 8 deletions
diff --git a/cmake/modules/FindSPANDSP.cmake b/cmake/modules/FindSPANDSP.cmake
index 6c64d8fdba..466982e85f 100644
--- a/cmake/modules/FindSPANDSP.cmake
+++ b/cmake/modules/FindSPANDSP.cmake
@@ -1,10 +1,10 @@
# Find the system's Spandsp includes and library
#
# SPANDSP_INCLUDE_DIRS - where to find spandsp.h
# SPANDSP_LIBRARIES - List of libraries when using spandsp
# SPANDSP_FOUND - True if spandsp found
# SPANDSP_DLL_DIR - (Windows) Path to the Spandsp DLL
# SPANDSP_DLL - (Windows) Name of the Spandsp DLL
include( FindWSWinLibs )
FindWSWinLibs( "spandsp-.*" "SPANDSP_HINTS" )
@@ -29,21 +29,21 @@ find_library( SPANDSP_LIBRARY
)
include( FindPackageHandleStandardArgs )
-find_package_handle_standard_args( Spandsp DEFAULT_MSG SPANDSP_INCLUDE_DIR SPANDSP_LIBRARY )
+find_package_handle_standard_args( SpanDSP DEFAULT_MSG SPANDSP_INCLUDE_DIR SPANDSP_LIBRARY )
if( SPANDSP_FOUND )
set( SPANDSP_INCLUDE_DIRS ${SPANDSP_INCLUDE_DIR} )
set( SPANDSP_LIBRARIES ${SPANDSP_LIBRARY} )
if (WIN32)
set ( SPANDSP_DLL_DIR "${SPANDSP_HINTS}/bin"
- CACHE PATH "Path to spandsp DLL"
+ CACHE PATH "Path to SpanDSP DLL"
)
file( GLOB _spandsp_dll RELATIVE "${SPANDSP_DLL_DIR}"
"${SPANDSP_DLL_DIR}/libspandsp-*.dll"
)
set ( SPANDSP_DLL ${_spandsp_dll}
# We're storing filenames only. Should we use STRING instead?
- CACHE FILEPATH "spandsp DLL file name"
+ CACHE FILEPATH "SpanDSP DLL file name"
)
mark_as_advanced( SPANDSP_DLL_DIR SPANDSP_DLL )
endif()
@@ -1,10 +1,10 @@
-# Find the system's Spandsp includes and library
+# Find the system's SpanDSP includes and library
#
# SPANDSP_INCLUDE_DIRS - where to find spandsp.h
@@ -1,10 +1,10 @@
#
# SPANDSP_INCLUDE_DIRS - where to find spandsp.h
-# SPANDSP_LIBRARIES - List of libraries when using spandsp
-# SPANDSP_FOUND - True if spandsp found
-# SPANDSP_DLL_DIR - (Windows) Path to the Spandsp DLL
-# SPANDSP_DLL - (Windows) Name of the Spandsp DLL
+# SPANDSP_LIBRARIES - List of libraries when using SpanDSP
+# SPANDSP_FOUND - True if SpanDSP found
+# SPANDSP_DLL_DIR - (Windows) Path to the SpanDSP DLL
+# SPANDSP_DLL - (Windows) Name of the SpanDSP DLL
include( FindWSWinLibs )
FindWSWinLibs( "spandsp-.*" "SPANDSP_HINTS" )